@@ -222,12 +222,13 @@ yumex="yumex"
 # Java install
 java()
 {
+mkdir /usr/java
 wget http://jdl.sun.com/webapps/download/AutoDL?BundleId=10336 -O jre-1.5.0_06-linux-i586.bin
 mv jre-1.5.0_06-linux-i586.bin /usr/java;chmod +x /usr/java/jre-1.5.0_06-linux-i586.bin
 dir=$(pwd)
 cd /usr/java
 ./jre-1.5.0_06-linux-i586.bin
-ln -s /usr/java/jre1.5.0_06/plugin/i386/ns7/libjavaplugin_oji.so /usr/lib/mozilla/plugins/libjavaplugin_oji.so
+ln -sf /usr/java/jre1.5.0_06/plugin/i386/ns7/libjavaplugin_oji.so /usr/lib/mozilla/plugins/libjavaplugin_oji.so
 export J2RE_HOME=/usr/java/jre1.5.0_06
 export PATH=$J2RE_HOME/bin:$PATH
 zenity --warning --text "Please turn your attention to the terminal; User input is needed." --title 'Warning!'
@@ -654,12 +655,13 @@ java_install()
 echo 'Install Java Runtime Enviromnent? (y for yes, n for no, c to cancel/exit)'
 read -n 1 java
 if [ $java = "y" ]; then
+ mkdir /usr/java
  wget http://jdl.sun.com/webapps/download/AutoDL?BundleId=10336 -O jre-1.5.0_06-linux-i586.bin
  mv jre-1.5.0_06-linux-i586.bin /usr/java;chmod +x /usr/java/jre-1.5.0_06-linux-i586.bin
  dir=$(pwd)
  cd /usr/java
  ./jre-1.5.0_06-linux-i586.bin
-  ln -s /opt/jre1.5.0_06/plugin/i386/ns7/libjavaplugin_oji.so /usr/lib/mozilla/plugins/libjavaplugin_oji.so
+  ln -sf /usr/java/jre1.5.0_06/plugin/i386/ns7/libjavaplugin_oji.so /usr/lib/mozilla/plugins/libjavaplugin_oji.so
   export J2RE_HOME=/opt/jre1.5.0_06
   export PATH=$J2RE_HOME/bin:$PATH
   /usr/sbin/alternatives --install /usr/bin/java java /usr/java/jre1.5.0_06/bin/java 2
